==> yexpert-js-0.0.112.tgz: package/www/js/TerminalPanel.js <==
/*

!----------------------------------------------------------------------------!
!                                                                            !
! Yexpert : (your) Système Expert sous Mumps GT.M et GNU/Linux               !
! Copyright (C) 2001-2015 by Hamid LOUAKED (HL).                             !
!                                                                            !
!----------------------------------------------------------------------------!

*/

"use strict"

var React = require('react');
var ReactBootstrap = require('react-bootstrap');
var {
  Panel,
  Grid,
  Row,
  Col
} = ReactBootstrap;

var TerminalPanel = React.createClass({

  getInitialState: function() {
    return {
      status: 'initial'
    }
  },

  componentWillMount: function() {
    this.controller = require('./controller-TerminalPanel')(this.props.controller, this);
    this.title = (
      <h1>Terminal Yexpert</h1>
    );
  },

  componentWillReceiveProps: function(newProps) {
    this.onNewProps(newProps);
  },

  render: function() {

    //var componentPath = this.controller.updateComponentPath(this);

    return (
      <Panel collapsible expanded={this.expanded} header={this.title}>
        {
        <Grid>
          <Row>
            <Col md={12}>
              <iframe height="430px" width="710px" src="http://localhost:8081/yrelay/yexpert-term/index.html" frameborder="0" allowfullscreen></iframe>
            </Col>
          </Row>
        </Grid>

        }
      </Panel>
    );
  }
});

module.exports = TerminalPanel;

==> yexpert-js-0.0.113.tgz: package/www/js/TerminalPanel.js <==
/*

!----------------------------------------------------------------------------!
!                                                                            !
! Yexpert : (your) Système Expert sous Mumps GT.M et GNU/Linux               !
! Copyright (C) 2001-2015 by Hamid LOUAKED (HL).                             !
!                                                                            !
!----------------------------------------------------------------------------!

*/

"use strict"

var React = require('react');
var ReactBootstrap = require('react-bootstrap');
var {
  Panel,
  Grid,
  Row,
  Col
} = ReactBootstrap;

var TerminalPanel = React.createClass({

  getInitialState: function() {
    return {
      status: 'initial'
    }
  },

  componentWillMount: function() {
    this.controller = require('./controller-TerminalPanel')(this.props.controller, this);
    this.title = (
      <h1>Terminal Yexpert</h1>
    );
  },

  componentWillReceiveProps: function(newProps) {
    this.onNewProps(newProps);
  },

  render: function() {

    //var componentPath = this.controller.updateComponentPath(this);

    return (
      <Panel collapsible expanded={this.expanded} header={this.title}>
        {
        <Grid>
          <Row>
            <Col md={12}>
              <iframe height="430px" width="710px" src="http://localhost:8081/yexpert-term/index.html" frameborder="0" allowfullscreen></iframe>
            </Col>
          </Row>
        </Grid>

        }
      </Panel>
    );
  }
});

module.exports = TerminalPanel;
